@@ -59,8 +59,22 @@ soft_quota_notification_interval = 1800
 
 class ApplicationQuota(object):
 
-    def __init__(self, db, expand_targets, message_send_enqueue, sender_app):
+    def __init__(self, db, expand_targets, message_send_enqueue, sender_app, rate_configs):
         self.db = db
+        # configure default rate limiting params for messages
+        hard_limit = rate_configs.get('hard_limit', 6000)
+        soft_limit = rate_configs.get('soft_limit', 600)
+        hard_duration = rate_configs.get('hard_duration', 1)
+        soft_duration = rate_configs.get('soft_duration', 1)
+        wait_time = rate_configs.get('wait_time', 3600)
+        plan_name = rate_configs.get('plan_name', None)
+        target_name = rate_configs.get('target_name', None)
+        target_role = rate_configs.get('target_role', None)
+        target = None
+        if target_name and target_role:
+            target = (target_name, target_role)
+        self.default_rate_def = (hard_limit, soft_limit, hard_duration, soft_duration, wait_time, plan_name, target)
+
         self.expand_targets = expand_targets
         self.message_send_enqueue = message_send_enqueue
         self.iris_application = None
@@ -95,6 +109,11 @@ class ApplicationQuota(object):
             for application, hard_limit, soft_limit, hard_duration, soft_duration, target_name, target_role, plan_name, wait_time in self.get_new_rules():
                 new_rates[application] = (hard_limit, soft_limit, hard_duration // 60, soft_duration // 60, wait_time, plan_name, (target_name, target_role))
 
+            # for any application that does not have a quota defined set it to a default value
+            for app in iris.cache.applications:
+                if not new_rates.get(app):
+                    new_rates[app] = self.default_rate_def
+
             old_keys = self.rates.keys()
             new_keys = new_rates.keys()
 
@@ -163,8 +182,9 @@ class ApplicationQuota(object):
 
         if hard_quota_usage > hard_limit:
             metrics.incr('quota_hard_exceed_cnt')
-            with self.last_incidents_mutex:
-                self.notify_incident(application, hard_limit, len(hard_buckets), plan_name, wait_time)
+            if plan_name:
+                with self.last_incidents_mutex:
+                    self.notify_incident(application, hard_limit, len(hard_buckets), plan_name, wait_time)
             return False
 
         # If soft limit breached, just notify owner and still send
@@ -177,8 +197,9 @@ class ApplicationQuota(object):
 
         if soft_quota_usage > soft_limit:
             metrics.incr('quota_soft_exceed_cnt')
-            with self.last_soft_quota_notification_time_mutex:
-                self.notify_target(application, soft_limit, len(soft_buckets), *target)
+            if target:
+                with self.last_soft_quota_notification_time_mutex:
+                    self.notify_target(application, soft_limit, len(soft_buckets), *target)
             return True
 
         return True
